pub struct CodeGenerator { /* private fields */ }Implementations
Sourceimpl CodeGenerator
impl CodeGenerator
pub fn new(config: GeneratorConfig) -> Self
pub fn builder() -> GeneratorConfigBuilder
Sourcepub fn generate(&self) -> Result<GeneratedCode>
pub fn generate(&self) -> Result<GeneratedCode>
Errors
Returns an error if no proto files are found, if protobuf compilation fails, or if configured paths are invalid.